# eisen-deploy
Eisen model deployment and inference library provides 
functionality to package
up trained models and use them in production.
 
Various deployment strategies are planned to be 
implemented within this package.

## Documentation
Documentation for this package is available at 
http://docs.eisen.ai

## Installation

This package can be installed as 

`pip install eisen_deploy`

or, as part of the standard Eisen distribution containing 
all the components within Eisen

`pip install eisen`
